miniconf -- Plain text Python built-in objects persistence

# `miniconf` -- Plain text Python built-in objects persistence

Sylvain Fourmanoit

syfou@users.sourceforge.net

### Abstract:

`miniconf` is a pure-Python module providing data persistence of a subset of built-in objects as plain text. It has been initially submitted as a patch against Python 2.5 tree (http://sourceforge.net/tracker/?func=detail&atid=355470&aid=1527597&group_id=5470). It is distributed here as a standalone module, in the hope it will be useful to the community, as well as to collect feedback. It should work on both Python 2.4 as well as on Python 2.5.